@@ -43,12 +43,19 @@ class IMapNavigatorPortlet(IPortletDataProvider):
     )
     
     levels = schema.TextLine(
-        title=_(u""),
+        title=_(u"Marker levels"),
         description=_(u"There are 3 sizes of markers. Choose the number of results at which the size increses. ex: '1,3,4' will have a small marker for 1 result medium marker for 2 or 3 results and a big marker for 4 or higher."),
         default=u'1,3,4',
         required=False
     )
     
+    description = schema.TextLine(
+        title=_(u"Description"),
+        description=_(u"Description text to add to the portlet"),
+        default=u'',
+        required=False
+    )
+    
 class Assignment(base.Assignment):
     """Portlet assignment.
 
@@ -58,11 +65,12 @@ class Assignment(base.Assignment):
 
     implements(IMapNavigatorPortlet)
 
-    def __init__(self, navigator=u'search', rootCategory=u'', visualTitle=u'Locations', levels=u'1,3,4'):
+    def __init__(self, navigator=u'search', rootCategory=u'', visualTitle=u'Locations', levels=u'1,3,4', description=u''):
 	self.navigator = navigator
 	self.rootCategory = rootCategory
 	self.visualTitle = visualTitle
 	self.levels = levels
+	self.description = description
 
     @property
     def title(self):
@@ -96,6 +104,9 @@ class Renderer(base.Renderer, CategoryUtils):
     def Title(self):
 	return self.data.visualTitle
     
+    def Description(self):
+	return self.data.description
+    
     def getXPosition(self, region=None):
 	if region is not None:
 	    registry = getUtility(IRegistry)
